.. NOTES FOR CREATING A RELEASE:
..
..   * bumpversion {major|minor|patch}
..   * git push && git push --tags
..   * python setup.py sdist upload
..   * convert into release https://github.com/deanmalmgren/textract/releases

textract
========

Extract text from most documents, with little fuss.


`Full documentation <http://textract.readthedocs.org>`__.

|Build Status| |Version| |Downloads| |Test Coverage| |Documentation Status|
|Updates| |Stars| |Forks|

.. |Build Status| image:: https://travis-ci.org/deanmalmgren/textract.svg?branch=master
   :target: https://travis-ci.org/deanmalmgren/textract

.. |Version| image:: https://img.shields.io/pypi/v/textract.svg
   :target: https://warehouse.python.org/project/textract/

.. |Downloads| image:: https://img.shields.io/pypi/dm/textract.svg
   :target: https://warehouse.python.org/project/textract/

.. |Test Coverage| image:: https://coveralls.io/repos/github/deanmalmgren/textract/badge.svg?branch=master
    :target: https://coveralls.io/github/deanmalmgren/textract?branch=master

.. |Documentation Status| image:: https://readthedocs.org/projects/textract/badge/?version=latest
   :target: https://readthedocs.org/projects/textract/?badge=latest

.. |Updates| image:: https://pyup.io/repos/github/deanmalmgren/textract/shield.svg
    :target: https://pyup.io/repos/github/deanmalmgren/textract/

.. |Stars| image:: https://img.shields.io/github/stars/deanmalmgren/textract.svg
    :target: https://github.com/deanmalmgren/textract/stargazers

.. |Forks| image:: https://img.shields.io/github/forks/deanmalmgren/textract.svg
    :target: https://github.com/deanmalmgren/textract/network
